@@ -13,7 +13,7 @@ OTHER_TEXT_SECTIONS='*(.mips16.fn.*) *(.mips16.call.*)'
 OTHER_GOT_SYMBOLS='
   _gp = ALIGN(16) + 0x7ff0;
 '
-OTHER_GOT_SECTIONS='
+OTHER_SDATA_SECTIONS='
   .lit8 : { *(.lit8) }
   .lit4 : { *(.lit4) }
 '
