@@ -244,6 +244,7 @@ main (argc, argv)
   link_info.new_dtags = false;
   link_info.flags = (bfd_vma) 0;
   link_info.flags_1 = (bfd_vma) 0;
+  link_info.pei386_auto_import = false;
 
   ldfile_add_arch ("");
 
@@ -326,7 +327,7 @@ main (argc, argv)
 	  else
 	    {
 	      /* We thought there was an external linker script. But
-	         we couldn't find it. Let's try gain for the internal
+	         we couldn't find it. Let's try again for the internal
 		 one without command_line.multilib_dir.  */
 	      char *saved = command_line.multilib_dir;
 	      command_line.multilib_dir = NULL;
